import { ButtonOne, ButtonOneWithScroll } from "../../components/Buttons";
import { H4, H5 } from "../../components/Headings";
import { HPTimeline } from "../../components/HP-timeline";
import { LoremMedium, LoremShort } from "../../components/Loremipsum";
import PreCyse from "../../components/precyse";
import { Section, Subesction } from "../../components/sections";
import { useNavigation } from "../../utils";
import { HPFeedback } from "./Feedback";    
import  { HP3new } from "./HP svgs/hp3";
import {WholeMendelow} from "./HP svgs/mendelows";
import { StakeholderManagement } from "./HP svgs/stakeholder-management";
import { SWOTone } from "./HP svgs/swots";
import { HPUnderstanding } from "./HP svgs/understanding";

export function HPIntegrated(){
    const { goToPageWithTabAndScroll} = useNavigation();

    return(
        <Section title="Integrated Human Practices" id="Integrated Human Practices">
            <Subesction title="Framework" id="Integrated Human Practices1">
                <p>Our team has defined a framework for managing interactions with stakeholders during each step of the project:
                </p>
                <ol>
  <li> <b>Stakeholder Management Framework </b>- To identify stakeholders and define how potential stakeholders fit our project.</li>
  <li><b>Power-Interest Matrix </b>- According to Mendelow to identify and evaluate the priorities of potential stakeholders.</li>
  <li><b>SWOT analysis</b> - Assessment of the strengths, weaknesses, opportunities and threats of the various groups previously identified as potential stakeholders.</li>
  <li><b>AREA Framework</b> - To structuring and optimizing project-related decisions.</li>
  <li><b>Feedback-Cycle</b> - To structure interactions with stakeholders for efficient and informative design and maximization of potential.</li>
  <li><b>Third-Party Feedback Templates </b>- To introduce the stakeholders, summarize the interactions and implement the output in our project.</li>
  <li><b>Cycle of Reflection</b> - According to Gibbs demonstrate the response and implementation as a part of our feedback cycle.</li>
</ol>
            <div className="row align-items-center" style={{marginTop: "5vh", marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOneWithScroll text="Stakeholder Management" scrollId="stakeH" open="stakemamange" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll text="Mendelow Analysis" open="mendelow"  scrollId="mendelowH" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll text="SWOT analysis" scrollId="swotH" open="swot" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
            </div>
            <div className="row align-items-center" style={{marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOneWithScroll scrollId="areaH" text="Feedback Cycle" open="area" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="thirdH" text="Third Party Feedback" open="thirdparty" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="feedH" text="Cycle of Reflection" open="feedcycle" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
                <div className="col">
                    <ButtonOneWithScroll scrollId="gibsonH" text="Gibson's Cycle" open="gibson" openclass="framecycletab"></ButtonOneWithScroll>
                </div>
            </div>
            <div className="col framecycletab" id="stakemamange" style={{display: "block"}}>
                <br/>
                <div className="align-items-center">
                <StakeholderManagement/>
                </div>  
                <H4 text="Stakeholder Management Framework" id="stakeH"/>
                <p>To clearly communicate to our stakeholders how they can support the <PreCyse/> project and the specific areas requiring 
                    their input, we developed a stakeholder management framework highlighting four key areas. Starting at the bottom right of the 
                    figure and moving clockwise, the first area needing feedback is <b>implementation</b>. It is crucial for our team to ensure that the project 
                    has all necessary components for realistic application in healthcare settings, focusing on the gene therapy treatment for cystic fibrosis.
                     This includes both the technical design and the appropriate business model to ensure successful implementation.
                </p>
                <p>The second key area is <b>sustainability and social impact.</b> We seek to understand how our project aligns with current healthcare initiatives and facilities in Germany and Europe, but also in the global situation and its interaction with social efforts related to CF awareness and gene therapy strategies.
                </p>
                <p>Next, we want to shape the <b>public perception</b> of our project, which uses synthetic biology to tackle a major healthcare challenge. We ask stakeholders about their knowledge and opinions on our gene therapeutic approach and its potential application to improve CF treatments.
                </p>
                <p>The final area involves <b>regulatory and safety considerations</b>. Given the stringent regulations governing healthcare in Germany, which vary by municipality, it is essential to consult with stakeholders familiar with these regulations to ensure our project complies with all necessary safety standards.
                </p>
            </div>
            <div className="col framecycletab" id="mendelow" style={{display: "none"}}>
                <H4 text="Power-Interest Matrix according to Mendelow" id="mendelowH"/>
                <p>Using the Mendelow Power-Interest Matrix, we classified the potential stakeholders associated with our project in terms of their power (the ability to provide important feedback on our project design and influence our project development) and interest in our project. The matrix consists of four quadrants arranged in descending order according to their priority level in the project:
                </p>
                <ul>
                <li>High Power, High Interest (Key Players)</li>
                <li>High Power, Low Interest (Keep Satisfied)</li>
                <li>Low Power, High Interest (Keep Informed)</li>
                <li>Low Power, Low Interest (Minimal Effort)</li>
                </ul>
                <p>This categorization helps to develop appropriate communication and management strategies for the different stakeholder groups and to ensure that their needs and influences are considered during the project.
                </p>
                <WholeMendelow/>
                <div className="row">
                    <div className="col">
                        <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-one", scrollToId: "keyplayersH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-1-neu.svg"/>
                        </a>
                    </div>
                    <div className="col">
                        <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-two", scrollToId: "keepH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-2.svg"/>
                        </a>
                    </div>
                    <div className="col">
                    <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-three", scrollToId: "informedH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-3-1.svg"/>
                        </a>
                    </div>
                    <div className="col">
                    <a onClick={() => goToPageWithTabAndScroll({path: "", tabId: "mendelow-four", scrollToId: "minimalH" })}>
                            <img src="https://static.igem.wiki/teams/5247/scientific-figures/mendelow-4.svg"/>
                        </a>
                    </div>
                </div>
                {/* TABS */}
                <div className="mendelowtab" id="mendelow-one" style={{display: "none"}}>
                    <H4 text="Key Players" id="keyplayersH"/>
                    <H5 text="High Power, High Interest - Priority Level 4"/>
                        <p>
                        Close support and extensive feedback are necessary to successfully implement PreCyse. 
                        Target groups include experts and physicians with expertise in gene therapy and treatment 
                        strategies for cystic fibrosis. The project has a reasonable, responsible, and future-oriented 
                        significance for the world. Furthermore, scientific-technological knowledge and biosafety are 
                        crucial. Collaboration with specialists in the field of gene therapy, cystic fibrosis, and different 
                        treatment strategies ensures the quality and effectiveness of the solutions developed.
                        </p>

                        <p><b>Scientific community and research institutions</b></p>
                        <p>
                        This group includes researchers, scientists, and research institutions specializing in gene editing 
                        and gene therapy. They have a high interest in the success of prime editing technology and have 
                        the power to significantly influence the project, be it through collaborations, scientific support, 
                        or critical reviews of the research results.
                        </p>

                        <p><b>Regulatory authorities (e.g. FDA, EMA)</b></p>
                        <p>
                        Regulatory agencies have both the power and the interest to ensure that gene therapy is safe and 
                        effective. They are crucial for the approval and authorization of the therapy for clinical use.
                        </p>


                </div>
                <div className="mendelowtab" id="mendelow-two" style={{display: "none"}}>
                    <H4 text=" Keep Satisfied" id="keepH"/>
                    <H5 text="High Power, Low Interest - Priority Level 3"/>
                    <p>
                    In order to successfully implement PreCyse, all concerns must be fully considered, even if they 
                    may differ from the project interests. CF specialists, bioethics specialists, and regulatory experts 
                    provide important information. Their input is beneficial to the implementation of our project. 
                    These categories of experts help to ensure that the project is ethical and compliant with the law. 
                    Their expertise ensures that all relevant aspects are covered.
                    </p>

                    <p><b>Government and public health authorities</b></p>
                    <p>
                    Although these stakeholders have some interest in new therapies that improve population health, 
                    their day-to-day interest may not be specifically focused on the iGEM project. However, they have 
                    the power to influence the project through funding, political support, or regulatory action.
                    </p>

                    <p><b>Pharmaceutical companies and industries</b></p>
                    <p>
                    Large pharmaceutical companies have the power to significantly support the project through 
                    investment or strategic partnerships. However, their interest may be low for the time being until 
                    the project has proven that it is commercially promising.
                    </p>

                </div>
                <div className="mendelowtab" id="mendelow-three" style={{display: "none"}}>
                    <H4 text="Keep Informed" id="informedH"/>
                    <H5 text="KEEP INFORMED - Low Power, High Interest - Priority Level 2"/>
                    <p> <b>Potential users of PreCyse</b> </p>
                    <p>
                    are important for understanding the needs, even if their expertise 
                    may not be sufficient to solve all the problems that arise in the project. It is therefore important to 
                    keep them informed. These users include stakeholders as their needs coincide with the project. 
                    Their feedback can provide valuable insights. This collaboration helps to better tailor the project 
                    to user needs.
                    </p>
                    <p><b>Patients and patient organizations</b></p>
                    <p>
                    
                    Patients suffering from cystic fibrosis and the organizations that support them have a high interest in 
                    new therapies that could improve their quality of life. However, their power to influence the project 
                    is limited.
                    </p>
                    <p> <b>Academic community and students</b></p>
                    <p>
                    
                    This group includes universities, professors, and students who are interested in the latest research 
                    in gene therapy. Although they do not have the direct power to influence the project, they can 
                    support and promote the project through research and academic publications.
                    </p>

                </div>
                <div className="mendelowtab" id="mendelow-four" style={{display: "none"}}>
                    <H4 text="Minimal Effort" id="minimalH"/>
                    <H5 text="Low Power, Low Interest - Priority Level 1" />
                        <p><b>Stakeholders who are regularly monitored</b></p>
                        <p>
                        may not be interested in the project and do not provide feedback. However, this can change over time. 
                        Stakeholders in this category are involved in the right situation. For example, the public of Bielefeld is 
                        essential for understanding the background information about the awareness of gene therapy or Cystic Fibrosis. 
                        Their involvement occurs when it is relevant and other groups of people cannot meet their needs.
                        </p>

                        <p><b>General public of Bielefeld</b></p>
                        <p>
                        The public may have little interest and power in relation to the specific iGEM project. While a certain level 
                        of education and awareness of the topic is important, intensive involvement of this group is generally not necessary.
                        </p>

                        <p><b>Media</b></p>
                        <p>
                        The media may have an interest in scientific breakthroughs and new technologies, but they tend to have little 
                        power in terms of directly influencing the project. Nevertheless, strategic communication with the media can 
                        be important to manage public perception.
                        </p>

                    
                </div>
                
            </div>
            <div className="col framecycletab" id="swot" style={{display: "none"}}>
                <H4 text="SWOT Analyses" id="swotH"/>
                <p>A <b>SWOT</b> analysis is a strategic tool used to evaluate the <b>S</b>trengths, <b>W</b>eaknesses, <b>O</b>pportunities, and <b>T</b>hreats of an 
                organization. In the context of our Human Practice approach, this analysis helps us identify internal strengths and weaknesses of our project, such as 
                technical capabilities and resource limitations, while also examining external opportunities, like potential collaborations, and threats, such as regulatory 
                challenges or public perception. 
                </p>
                <SWOTone/>

            <div className="row align-items-center" style={{marginTop: "5vh", marginBottom: "1vh"}}>
                <div className="col">
                    <ButtonOne text="Patients" open="pats" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Industry" open="inds" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Academia" open="acs" openclass="subcycletab"></ButtonOne>
                </div>
                <div className="col">
                    <ButtonOne text="Healthcare" open="healths" openclass="subcycletab"></ButtonOne>
                </div>
                </div>
                <div className="row align-items-center" style={{ marginBottom: "5vh"}}>
                <div className="col">
                    <ButtonOne text="Government" open="govs" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="Community" open="comms" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="The Public" open="pubs" openclass="subcycletab"></ButtonOne>
                    </div>
                    <div className="col">
                    <ButtonOne text="Business" open="busi" openclass="subcycletab"></ButtonOne>
                </div>
                </div>
                <div className="col subcycletab" id="pats" style={{display: "block"}}> 
                <H5 text="Patient Advocacy and Support Groups"/>
                <table cellPadding={10} cellSpacing={0} >
                   
                    <thead>
                        <tr>
                            <th>STRENGTHS</th>
                            <th>WEAKNESSES</th>
                            <th>OPPORTUNITIES</th>
                            <th>THREATS</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>Strong support network for patients</td>
                            <td>Limited funding and resources</td>
                            <td>Increased patient engagement and support for new therapies</td>
                            <td>Potential opposition from groups skeptical of new treatments</td>
                        </tr>
                        <tr>
                            <td>Influential in policy advocacy</td>
                            <td>Potential resistance to new technologies</td>
                            <td>Advocacy can drive policy changes</td>
                            <td>Misinformation or miscommunication about new therapies</td>
                        </tr>
                        <tr>
                            <td>Personal connection to patient communities</td>
                            <td>Dependence on donations and grants</td>
                            <td>Enhancing awareness and education</td>
                            <td>Competing priorities among advocacy groups</td>
                        </tr>
                    </tbody>
                </table>

                </div>
                <div className="col subcycletab" id="inds" style={{display: "none"}}>
                <H5 text="Genetic Research Institutions" />
<table cellPadding={10} cellSpacing={0}>
    <thead>
        <tr>
            <th>STRENGTHS</th>
            <th>WEAKNESSES</th>
            <th>OPPORTUNITIES</th>
            <th>THREATS</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>Expertise in genetic disorders and advanced research capabilities</td>
            <td>May have limited practical experience with therapy delivery</td>
            <td>Collaboration can lead to breakthroughs in gene editing</td>
            <td>High competition for funding and research grants</td>
        </tr>
        <tr>
            <td>Access to state-of-the-art research facilities</td>
            <td>Potential disconnect between research and clinical application</td>
            <td>Potential for groundbreaking research and new discoveries</td>
            <td>Rapid technological changes requiring constant adaptation</td>
        </tr>
        <tr>
            <td>Strong track record of innovation</td>
            <td>High operational costs</td>
            <td>Collaborative research opportunities</td>
            <td>Ethical and regulatory challenges</td>
        </tr>
    </tbody>
</table>
    
                </div>
                <div className="col subcycletab" id="acs" style={{display: "none"}}>acs </div>
                <div className="col subcycletab" id="healths" style={{display: "none"}}> healths </div>
                <div className="col subcycletab" id="govs" style={{display: "none"}}>govs </div>
                <div className="col subcycletab" id="comms" style={{display: "none"}}>comms </div>
                <div className="col subcycletab" id="pubs" style={{display: "none"}}>pubs </div>
                <div className="col subcycletab" id="busi" style={{display: "none"}}>busi </div>
            </div>
            <div className="col framecycletab" id="thirdparty" style={{display: "none"}}>
               <H4 text="The Third-Party Feedback Template" id="thirdH"/>
                <p>To drive stakeholder interactions for the <PreCyse/> project, our team implemented the “Third-Party Feedback Template”. This template helps us introduce individuals to our stakeholders and demonstrate their significance to our project. There are three main sections in this template. First, we address the important question of who our stakeholders are, introducing their backgrounds and explaining why we reached out to them. Next, we summarize the conversations and knowledge exchanged during our interactions. Finally, we share our reflections from these stakeholder conversations and how these interactions have guided the next steps of our project.  </p>
                    <div className="col-4">
                        <div className="" >
                            <HPUnderstanding/> 
                        </div> 
                    </div>
                    <div className="col">
                        <div className="col understandingtab" id="under-reflection" style={{display: "block"}}>
                            <div><LoremShort/></div>
                        </div>
                        <div className="col understandingtab" id="under-responsibility" style={{display: "none"}}>
                            <div><LoremShort/></div>
                        </div>
                        <div className="col understandingtab" id="under-responsive" style={{display: "none"}}>
                            <div><LoremShort/></div>
                        </div>
                    </div>
            </div>
            <div className="col framecycletab" id="area" style={{display: "none"}}>
                <H4 text="AREA Framework" id="areaH"/>
                <p>The AREA Framework Analysis is a model that helps structure and optimize decision-making in complex projects, especially when multiple stakeholders are involved.
                </p>
                <div id="hp3-wrapper">
                    <div className="col">
                    <HP3new/>
                    </div>
                </div>
                <H5 text="Agenda"/>
                <p>
    The central goal of the PreCyse project is to develop an innovative gene therapy solution for cystic fibrosis (CF) that is not only technically effective but also socially acceptable and ethically justifiable. The primary questions include:
</p>
<ul>
    <li>How can the project improve the lives of CF patients?</li>
    <li>How can the project ensure that the proposed therapy meets ethical and regulatory standards?</li>
    <li>How can the solution be integrated into current healthcare initiatives?</li>
    <li>How does the project influence, and how is it influenced by, the perceptions of stakeholders, particularly patients, regulatory authorities, and the scientific community?</li>
</ul>
<p>
    Here, the need is defined to develop a holistic understanding of the project’s impacts, considering both technological aspects and human perspectives.
</p>

                <H5 text="Research"/>
                <p>
    To gain a comprehensive understanding of the needs and expectations, the PreCyse team employed various methods to collect data from relevant stakeholders, including:
</p>
<p>
    <b>Surveys of CF patients and their families:</b> These provided insights into the specific challenges and needs that CF patients face in daily life. Critical questions regarding safety, accessibility, and the long-term application of gene technology were addressed.
</p>
<p>
    <b>Expert consultations with researchers and physicians:</b> Scientists and doctors working in gene therapy provided essential technical feedback and helped assess the feasibility and effectiveness of the proposed therapy.
</p>
<p>
    <b>Regulatory authorities:</b> Feedback from agencies like the FDA and EMA played a central role in assessing safety requirements and regulatory challenges that need to be addressed before clinical application. This research phase was critical to ensuring that the technical solution aligned with patient needs and regulatory standards.
</p>

                <H5 text="Evaluation"/>
                <p>Based on the research phase results, a detailed assessment of the strengths, weaknesses, opportunities, and threats (SWOT analysis) was conducted (see above). The evaluation helped the team reflect on the gathered insights and focus on key challenges to ensure long-term feasibility and acceptance.
                </p>
                <H5 text="Agenda"/>
                <p>
    Based on the analysis, several measures were taken to ensure that the PreCyse project is not only scientifically advanced but also socially and regulatorily acceptable:
</p>
<p>
    <b>Integrated feedback loops:</b> Stakeholders were continuously involved, and their feedback was directly incorporated into the adaptation and improvement of the project design. An example of this is the application of Gibbs' Reflection Cycle to ensure that all feedback is thoroughly analyzed and incorporated into future decisions.
</p>
<p>
    <b>Regulatory and ethical adjustments:</b> By working closely with regulatory authorities and ethics committees, measures were taken to ensure that the project complies with regulatory requirements and remains ethically justifiable.
</p>
<p>
    <b>Safety considerations:</b> The safety of the therapy was a key concern in stakeholder interactions. Specific safety protocols were developed to minimize risks for patients.
</p>
<p>
    <b>Public awareness:</b> To increase public awareness of the potential and safety of gene technologies, targeted communication measures were taken to address misunderstandings and improve acceptance of the technology.
</p>

            </div>
            <div className="col framecycletab" id="feedcycle" style={{display: "none"}}> 
                <H4 text="The Feedback Cycle of our IHP Approach" id="feedH"/>
                <p>To foster productive conversations and ensure our team maximizes each stakeholder interaction for the PreCyse project, we developed a feedback cycle that outlines a structured approach for our meetings. The first step in our cycle involves listening to each stakeholder's experiences, personal stories, or insights. Our team then follows up by asking relevant questions to dive deeper into the shared information or to introduce new topics or directions in the conversation. Towards the end of the meeting, we ask clarifying questions and reiterate key points to ensure our understanding is accurate and that the stakeholder has no additional input. Finally, we explore new directions and ideas inspired by the stakeholder interaction, encouraging our team to pursue innovative and novel concepts.
                </p>
                <div>
                    <img src="https://static.igem.wiki/teams/5247/scientific-figures/feedbackcycle.svg"/>
                </div>

            </div>
            <div className="col framecycletab" id="gibson" style={{display: "none"}}> 
                <H4 text="Cycle of Reflections according to Gibbs" id="gibsonH"/>
                <p>For the <PreCyse/> project to impact the world, it needs to work with all types of stakeholders. Therefore, we are optimizing Gibb's Reflection Cycle to demonstrate our inclusive response to the challenges we encountered during our iGEM journey. The cycle includes the impetus for our engagement, the unbiased two-way communication with stakeholders, our thorough analysis of the feedback and our actions to implement the stakeholder inputs into our project.
                </p>
                <div style={{height: "20%"}}>
                    <img src="https://static.igem.wiki/teams/5247/scientific-figures/gibbsreflection.svg" style={{height: "20%"}}/>
                </div>
                <p>
    <b>Impetus:</b> When developing a systematic approach to a recurring problem, it's easy to get distracted by multiple points of view. We need to prioritize quality over quantity. This section presents the successive impetus that drives the continuous implementation of Human Practices activities.
</p>
<p>
    <b>Two-way communication:</b> For our solution to be human-centered, the two-way communication method is to communicate to stakeholders the values we are incorporating into our project design. We make sure they understand the project clearly so that they can articulate their concerns and suggestions precisely.
</p>
<p>
    <b>Analysis:</b> The two-way communication with our stakeholders is carefully analyzed. In this section, stakeholder feedback is processed and turned into constructive guidance for project implementation, allowing us to consider what work should be prioritized to best address stakeholder concerns.
</p>
<p>
    <b>Implementation:</b> Implementation shows our measures for evaluating and refining the project. These actions are fully integrated into the project designs and other parts of our project to ensure that our project and activities are good, responsible and engaging for the world.
</p>
<p>
    In the areas of <b>Communication & Implementation</b>, <b>Necessity & Relevance</b>, <b>Science & Technology</b>, <b>Ethics & Regulation</b>, our Human Practice activities are conducted with X groups of stakeholders throughout our iGEM journey. In doing so, we explore the contexts that define projects, idealize solutions and evaluate outcomes for our human practice approach.
</p>

            </div>
            </Subesction>
            <Subesction title="Timeline" id="Integrated Human Practices2">
                <HPTimeline/>
            </Subesction>
            <Subesction title="Implementation & Feedback" id="Integrated Human Practices3">
                
                <HPFeedback/>
            </Subesction>
            <Subesction title="Conclusion" id="Integrated Human Practices4">
                <LoremMedium/>
            </Subesction>
        </Section>
    )
}